export declare namespace ECS {
    type Message = Base & Partial<{
        agent: Agent;
        client: Client;
        custom: Record<string, unknown>;
        ecs: Meta;
        error: Error;
        host: Host;
        http: HTTP;
        log: Log;
        metrics: Record<string, number>;
        networkInformation: NetworkInformation;
        screen: Record<string, string>;
        service: Service;
        tracing: Tracing;
        url: Url;
        user_agent: UserAgent;
    }>;
    type Base = Partial<{
        '@timestamp': string;
        labels: Record<string, string>;
        message: string;
        tags: string[];
    }>;
    type Agent = Partial<{
        ephemeral_id: string;
        id: string;
        name: string;
        type: string;
        version: string;
    }>;
    type HTTP = Partial<{
        request: Request;
        response: Response;
    }>;
    type Request = Partial<{
        body: Body;
        bytes: number;
        method: string;
        referrer: string;
    }>;
    type Response = Partial<{
        body: Body;
        bytes: number;
        status_code: number;
        version: string;
    }>;
    type Body = Partial<{
        bytes: number;
        content: string;
    }>;
    type NetworkInformation = Partial<{
        downlink: number;
        effectiveType: string;
        rtt: number;
    }>;
    type Meta = Partial<{
        version: string;
    }>;
    type Client = Partial<{
        address: string;
        bytes: number;
        domain: string;
        geo: Geo;
        ip: string;
        mac: string;
        packets: number;
        port: number;
        registered_domain: string;
        top_level_domain: string;
        user: User;
    }>;
    type Url = Partial<{
        domain: string;
        extension: string;
        fragment: string;
        full: string;
        original: string;
        password: string;
        path: string;
        port: string;
        query: string;
        registered_domain: string;
        scheme: string;
        top_level_domain: string;
        username: string;
    }>;
    type User = Partial<{
        domain: string;
        email: string;
        full_name: string;
        hash: string;
        id: string;
        name: string;
    }>;
    type UserAgent = Partial<{
        device: UserAgentDevice;
        name: string;
        original: string;
        os: UserAgentOs;
        version: string;
    }>;
    type UserAgentDevice = Partial<{
        name: string;
    }>;
    type UserAgentOs = Partial<{
        family: string;
        full: string;
        kernel: string;
        name: string;
        platform: string;
        version: string;
    }>;
    type Geo = Partial<{
        city_name: string;
        continent_name: string;
        country_iso_code: string;
        country_name: string;
        location: string;
        name: string;
        region_iso_code: string;
        region_name: string;
    }>;
    type Error = Partial<{
        code: string;
        id: string;
        message: string;
        stack_trace: string;
        type: string;
    }>;
    type Service = Partial<{
        ephemeral_id: string;
        id: string;
        name: string;
        node: ServiceNode;
        state: string;
        type: string;
        version: string;
    }>;
    type ServiceNode = Partial<{
        name: string;
    }>;
    type Log = Partial<{
        level: 'error' | 'debug' | 'warning';
        logger: string;
        original: string;
    }>;
    type Tracing = Partial<{
        id: string;
    }>;
    type Host = Partial<{
        architecture: string;
        domain: string;
        hostname: string;
        id: string;
        ip: string;
        mac: string;
        name: string;
        type: string;
        uptime: number;
    }>;
}
